<?php
/*
Plugin Name: WooCommerce No Variation Image Overlay
Plugin URI: http://abbysdoor.com
Description: When a product variation does not have its own image, add an overlay image to the primary product image. You must have WooCommerce installed to use this plugin. Settings for this plugin are under WooCommerce > Settings > Product > No Variation Image.
Version: 1.0
Author: Abby Langner
Author URI: http://abbysdoor.com
Text Domain: al_woo_novarimage
Domain Path: /languages
License: Public Domain
*/

load_plugin_textdomain( 'al_woo_novarimage', false, dirname( plugin_basename( __FILE__ ) ) . '/languages' );

//Register Activation/Deactivation/Uninstall Cleanup Hooks
//    Uninstall hook will be serialized, so we cannot use a closure.
//    For consistency, all cleanup functions use function notation with prefix.
register_activation_hook( __FILE__, 'al_woo_novarimage_activate');
register_deactivation_hook( __FILE__, 'al_woo_novarimage_deactivate');
register_uninstall_hook( __FILE__, 'al_woo_novarimage_uninstall');
function al_woo_novarimage_activate(){
}
function al_woo_novarimage_deactivate(){   
}
function al_woo_novarimage_uninstall(){
    delete_option( 'al_woo_novarimage_attachment' );
}

//Add Image-URL Option to WooCommerce Settings
add_filter( 'woocommerce_get_sections_products', function( $sections ) {
	$sections['al_woo_novarimage'] = __( 'No Variation Image', 'al_woo_novarimage' );
	return $sections;
});
add_filter( 'woocommerce_get_settings_products', function( $settings, $current_section ){
	if ( $current_section == 'al_woo_novarimage' ) {
		$settings_novarimage = array();
		$settings_novarimage[] = array( 
            'name' => __( 'No Variation Image', 'al_woo_novarimage' ), 
            'type' => 'title', 
            'desc' => __( 'Choose the image to overlay when no image is available for a product variation.', 'al_woo_novarimage' ), 
            'id' => 'al_woo_novarimage' 
        );
		$settings_novarimage[] = array(
			'name'     => __( 'Image URL', 'al_woo_novarimage' ),
			'desc_tip' => __( 'ID of the image from the media library.', 'al_woo_novarimage' ),
			'id'       => 'al_woo_novarimage_attachment',
			'type'     => 'text',
			'desc'     => __( 'URL to an image you want to show when no variation image is available. Upload images using the media uploader (Admin > Media)', 'al_woo_novarimage' ),
		);
		$settings_novarimage[] = array( 'type' => 'sectionend', 'id' => 'al_woo_novarimage' );
		return $settings_novarimage;
	} else { //not our settings, don't touch!
		return $settings;
	}
}, 10, 2 );

//Add Easier Way to Find the Setting
add_filter( "plugin_action_links_".plugin_basename(__FILE__), function( $links ){
	$settings_link = '<a href="admin.php?page=wc-settings&tab=products&section=al_woo_novarimage">' . __( 'Settings' ) . '</a>';
    array_unshift( $links, $settings_link );
  	return $links;
} );

//Modify Product Page
//(Print Image-URL to hidden DIV that JavaScript can manipulate)
add_action( 'woocommerce_before_variations_form', function(){
	$savedurl = get_option( 'al_woo_novarimage_attachment', 0 );
	$mediaurl = plugins_url( '/sorry.png' , __FILE__ );
	if($savedurl){
		$mediaurl = $savedurl;
	}
	echo '<div class="woo-novarimage-default" style="display:none;" data-url="'
		.$mediaurl
		.'"></div>';
});
add_action( 'wp_enqueue_scripts', function(){
	wp_enqueue_script(
		'al_woo_novarimage',
		plugins_url( '/al_woo_novarimage.js' , __FILE__ ),
		array( 'jquery' )
	);
});
